==> dropzone-ui-2.1.1.tgz: package/CHANGELOG.md <==
# Change Log

<p align="center">
<img align="center" height="120" src="https://user-images.githubusercontent.com/43678736/132112022-0ca409ae-cca2-43c8-be89-110376260a3f.png" alt="dropone-ui-logo">

<h1 align="center">  Dropzone-UI</h1>

</p>

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

<a name="2.1.0"></a>

## [2.1.0](https://github.com/dropzone-ui/dropzone-ui/compare/v2.1.0...v2.0.0) (2021-09-28)

### Features

- Add preventDefault function on InputButton component
- Improve Readme.md
- Add Openbase badge
- Improve description

<a name="2.0.0"></a>

## [2.0.0](https://github.com/dropzone-ui/dropzone-ui/compare/v2.0.0...v1.2.10) (2021-09-21)

### Features

- Improve Readme.md
- Add localization for Spanish and English
- Add Readme_es.md file

<a name="1.2.10"></a>

## [1.2.10](https://github.com/dropzone-ui/dropzone-ui/compare/v1.0.1...v1.0.2) (2021-09-21)

### Features

- Improve Readme.md
- Add quiality badge
<a name="1.2.9"></a>

## [1.2.9](https://github.com/dropzone-ui/dropzone-ui/compare/v1.0.1...v1.0.2) (2021-09-12)

### Features

- Release Input File Button
- Release FileItemContainer Compnent
- Improve API doc for all components (now arranged alphabetically)



<a name="1.1.28"></a>

## [1.1.28](https://github.com/dropzone-ui/dropzone-ui/compare/v1.0.1...v1.0.2) (2021-09-09)

### Features

- Minor bug fixed, upload status not hiding on info open fixed


<a name="1.0.28"></a>

## [1.0.28](https://github.com/dropzone-ui/dropzone-ui/compare/v1.0.1...v1.0.2) (2021-09-08)

### Features

- added readme status badges 

- Add Travis ci and coveralls integration 

- update README description 
- Dropzone, FileItem and FullScreenImage components released

<a name="1.0.1"></a>

## [1.0.1](https://github.com/dropzone-ui/dropzone-ui/compare/v1.0.0...v1.0.1) (2021-08-28)

### Features

- README improvements

<a name="1.0.0"></a>

# [1.0.0](https://github.com/dropzone-ui/dropzone-ui/compare/v0.1.2...v1.0.0) (2021-08-28)

==> dropzone-ui-5.0.0.tgz: package/CHANGELOG.md <==
# Change Log

<p align="center">
<img align="center" height="120" src="https://user-images.githubusercontent.com/43678736/132112022-0ca409ae-cca2-43c8-be89-110376260a3f.png" alt="dropone-ui-logo">

<h1 align="center">  Dropzone-UI</h1>

</p>

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

<a name="3.0.1"></a>

## [3.0.1](https://github.com/dropzone-ui/dropzone-ui/compare/v2.8.1...v3.0.1) (2021-10-11)

### Features

- Translation support for `Portuguese`.
<a name="2.8.1"></a>

## [2.8.1](https://github.com/dropzone-ui/dropzone-ui/compare/v2.8.1...v2.1.1) (2021-10-08)

### Features
- Translation support for `French`.

<a name="2.1.1"></a>

## [2.1.1](https://github.com/dropzone-ui/dropzone-ui/compare/v2.1.1...v2.0.0) (2021-10-01)

### Features

- Fixed issue on tsconfig.json that affected build process

<a name="2.1.0"></a>

## [2.1.0](https://github.com/dropzone-ui/dropzone-ui/compare/v2.1.0...v2.0.0) (2021-09-28)

### Features

- Add preventDefault function on InputButton component
- Improve Readme.md
- Add Openbase badge
- Improve description

<a name="2.0.0"></a>

## [2.0.0](https://github.com/dropzone-ui/dropzone-ui/compare/v2.0.0...v1.2.10) (2021-09-21)

### Features

- Improve Readme.md
- Add localization for `Spanish` and `English`
- Add Readme_es.md file

<a name="1.2.10"></a>

## [1.2.10](https://github.com/dropzone-ui/dropzone-ui/compare/v1.0.1...v1.0.2) (2021-09-21)

### Features

- Improve Readme.md
- Add quiality badge
<a name="1.2.9"></a>

## [1.2.9](https://github.com/dropzone-ui/dropzone-ui/compare/v1.0.1...v1.0.2) (2021-09-12)

### Features

- Release Input File Button
- Release FileItemContainer Compnent
- Improve API doc for all components (now arranged alphabetically)



<a name="1.1.28"></a>

## [1.1.28](https://github.com/dropzone-ui/dropzone-ui/compare/v1.0.1...v1.0.2) (2021-09-09)

### Features

- Minor bug fixed, upload status not hiding on info open fixed


<a name="1.0.28"></a>

## [1.0.28](https://github.com/dropzone-ui/dropzone-ui/compare/v1.0.1...v1.0.2) (2021-09-08)

### Features

- added readme status badges 

- Add Travis ci and coveralls integration 

- update README description 
- Dropzone, FileItem and FullScreenImage components released

<a name="1.0.1"></a>

## [1.0.1](https://github.com/dropzone-ui/dropzone-ui/compare/v1.0.0...v1.0.1) (2021-08-28)

### Features

- README improvements

<a name="1.0.0"></a>

# [1.0.0](https://github.com/dropzone-ui/dropzone-ui/compare/v0.1.2...v1.0.0) (2021-08-28)
